@@ -18,23 +18,30 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef HISTORY_CHAT_CONFIGURATION_WIDGET_FACTORY_H
-#define HISTORY_CHAT_CONFIGURATION_WIDGET_FACTORY_H
-
-#include <QtCore/QPointer>
+#pragma once
 
 #include "gui/widgets/chat-configuration-widget-factory.h"
 
-class OtrPolicyService;
+#include <QtCore/QObject>
+#include <QtCore/QPointer>
+#include <injeqt/injeqt.h>
 
-class HistoryChatConfigurationWidgetFactory : public ChatConfigurationWidgetFactory
+class PluginInjectedFactory;
+
+class HistoryChatConfigurationWidgetFactory : public QObject, public ChatConfigurationWidgetFactory
 {
-
+	Q_OBJECT
+	
 public:
+	Q_INVOKABLE explicit HistoryChatConfigurationWidgetFactory(QObject *parent = nullptr);
 	virtual ~HistoryChatConfigurationWidgetFactory();
 
 	virtual ChatConfigurationWidget * createWidget(const Chat &chat, QWidget *parent);
 
-};
+private:
+	QPointer<PluginInjectedFactory> m_pluginInjectedFactory;
 
-#endif // HISTORY_CHAT_CONFIGURATION_WIDGET_FACTORY_H
+private slots:
+	INJEQT_SET void setPluginInjectedFactory(PluginInjectedFactory *pluginInjectedFactory);
+
+};
