@@ -18,32 +18,53 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef JABBER_URL_HANDLER_H
-#define JABBER_URL_HANDLER_H
-
-#include <QtCore/QObject>
-#include <QtCore/QRegExp>
+#pragma once
 
 #include "url-handlers/url-handler.h"
 
+#include <QtCore/QObject>
+#include <QtCore/QPointer>
+#include <QtCore/QRegExp>
+#include <injeqt/injeqt.h>
+
+class AccountManager;
+class ChatManager;
+class ChatStorage;
+class ChatWidgetManager;
+class ContactManager;
+class IconsManager;
+
 class QAction;
 
 class JabberUrlHandler : public QObject, public UrlHandler
 {
 	Q_OBJECT
 
-	QRegExp JabberRegExp;
-
-private slots:
-	void accountSelected(QAction *action);
-
 public:
-	JabberUrlHandler();
+	Q_INVOKABLE explicit JabberUrlHandler(QObject *parent = nullptr);
 	virtual ~JabberUrlHandler();
 
 	virtual bool isUrlValid(const QByteArray &url);
-	virtual void openUrl(const QByteArray &url, bool disableMenu = false);
+	virtual void openUrl(UrlOpener *urlOpener, const QByteArray &url, bool disableMenu = false);
+
+private:
+	QPointer<AccountManager> m_accountManager;
+	QPointer<ChatManager> m_chatManager;
+	QPointer<ChatStorage> m_chatStorage;
+	QPointer<ChatWidgetManager> m_chatWidgetManager;
+	QPointer<ContactManager> m_contactManager;
+	QPointer<IconsManager> m_iconsManager;
+
+	QRegExp m_jabberRegExp;
+
+private slots:
+	INJEQT_SET void setAccountManager(AccountManager *accountManager);
+	INJEQT_SET void setChatManager(ChatManager *chatManager);
+	INJEQT_SET void setChatStorage(ChatStorage *chatStorage);
+	INJEQT_SET void setChatWidgetManager(ChatWidgetManager *chatWidgetManager);
+	INJEQT_SET void setContactManager(ContactManager *contactManager);
+	INJEQT_SET void setIconsManager(IconsManager *iconsManager);
+
+	void accountSelected(QAction *action);
 
 };
-
-#endif // JABBER_URL_HANDLER_H
